==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/SdkmessageprocessingstepsecureconfigCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Sdkmessageprocessingstepsecureconfig;
import microsoft.dynamics.crm.entity.request.SdkmessageprocessingstepRequest;
import microsoft.dynamics.crm.entity.request.SdkmessageprocessingstepsecureconfigRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class SdkmessageprocessingstepsecureconfigCollectionRequest extends CollectionPageEntityRequest<Sdkmessageprocessingstepsecureconfig, SdkmessageprocessingstepsecureconfigRequest>{

    protected ContextPath contextPath;

    public SdkmessageprocessingstepsecureconfigCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Sdkmessageprocessingstepsecureconfig.class, cp -> new SdkmessageprocessingstepsecureconfigRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SdkmessageprocessingstepCollectionRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep() {
        return new SdkmessageprocessingstepCollectionRequest(contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep"), Optional.empty());
    }

    public SdkmessageprocessingstepRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep(String sdkmessageprocessingstepid) {
        return new SdkmessageprocessingstepRequest(contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep").addKeys(new NameValue(sdkmessageprocessingstepid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/SdkmessageprocessingstepsecureconfigCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Sdkmessageprocessingstepsecureconfig;
import microsoft.dynamics.crm.entity.request.SdkmessageprocessingstepRequest;
import microsoft.dynamics.crm.entity.request.SdkmessageprocessingstepsecureconfigRequest;

public class SdkmessageprocessingstepsecureconfigCollectionRequest extends CollectionPageEntityRequest<Sdkmessageprocessingstepsecureconfig, SdkmessageprocessingstepsecureconfigRequest>{

    protected ContextPath contextPath;

    public SdkmessageprocessingstepsecureconfigCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Sdkmessageprocessingstepsecureconfig.class, cp -> new SdkmessageprocessingstepsecureconfigRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SdkmessageprocessingstepCollectionRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep() {
        return new SdkmessageprocessingstepCollectionRequest(contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep"), Optional.empty());
    }

    public SdkmessageprocessingstepRequest sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep(String sdkmessageprocessingstepid) {
        return new SdkmessageprocessingstepRequest(contextPath.addSegment("sdkmessageprocessingstepsecureconfigid_sdkmessageprocessingstep").addKeys(new NameValue(sdkmessageprocessingstepid.toString())), Optional.empty());
    }

}
